﻿using LawFirmContracts.BindingModels;
using LawFirmContracts.StoragesContracts;
using LawFirmContracts.ViewModels;
using LawFirmDataModels.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using System.Threading.Tasks;

namespace LawFirmDatabaseImplement.Models
{
	[DataContract]
	public class Implementer : IImplementerModel
    {
		[DataMember]
		public int Id { get; private set; }
		[DataMember]
		public string ImplementerFIO { get; private set; } = string.Empty;
		[DataMember]
		public string Password { get; private set; } = string.Empty;
		[DataMember]
		public int WorkExperience { get; private set; }
		[DataMember]
		public int Qualification { get; private set; }

        [ForeignKey("ImplementerId")]
        public virtual List<Order> Orders { get; private set; } = new();

        public static Implementer? Create(ImplementerBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new()
            {
                Id = model.Id,
                ImplementerFIO = model.ImplementerFIO,
                Password = model.Password,
                Qualification = model.Qualification,
                WorkExperience = model.WorkExperience,
            };
        }

        public void Update(ImplementerBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            ImplementerFIO = model.ImplementerFIO;
            Password = model.Password;
            Qualification = model.Qualification;
            WorkExperience = model.WorkExperience;
        }

        public ImplementerViewModel GetViewModel => new()
        {
            Id = Id,
            ImplementerFIO = ImplementerFIO,
            Password = Password,
            Qualification = Qualification,
            WorkExperience = WorkExperience,
        };
    }
}
